@@ -13,17 +13,17 @@
 /*
  * No description
  */
-class EditArrayOrderDlg : public wxScrollingDialog
+class DLLIMPORT EditArrayOrderDlg : public wxScrollingDialog
 {
 	public:
 		// class constructor
-		EditArrayOrderDlg(wxWindow* parent, const wxArrayString& array = 0L);
+		EditArrayOrderDlg(wxWindow* parent, const wxArrayString& array);
 		// class destructor
-		~EditArrayOrderDlg();
+		~EditArrayOrderDlg() override;
 		EditArrayOrderDlg& operator=(const EditArrayOrderDlg&){ return *this; } // just to satisfy script bindings (never used)
-		void SetArray(const wxArrayString& array){ m_Array = array; }
+		void SetArray(const wxArrayString& array);
 		const wxArrayString& GetArray(){ return m_Array; }
-		void EndModal(int retCode);
+		void EndModal(int retCode) override;
 		void OnMoveUp(wxCommandEvent& event);
 		void OnMoveDown(wxCommandEvent& event);
 		void OnUpdateUI(wxUpdateUIEvent& event);
