@@ -23,7 +23,6 @@
 DLLIMPORT extern int ID_NBEditorManager;
 DLLIMPORT extern int ID_EditorManager;
 DLLIMPORT extern int idEditorManagerCheckFiles;
-DLLIMPORT extern int ID_EditorManagerCloseButton;
 
 // forward decls
 class EditorBase;
@@ -61,11 +60,8 @@ class DLLIMPORT EditorManager : public Mgr<EditorManager>, public wxEvtHandler
         friend class Mgr<EditorManager>;
         static bool s_CanShutdown;
     public:
-        EditorManager& operator=(cb_unused const EditorManager& rhs) // prevent assignment operator
-        {
-            cbThrow(_T("Can't assign an EditorManager* !!!"));
-            return *this;
-        }
+        EditorManager(const EditorManager&) = delete;
+        EditorManager& operator=(const EditorManager&) = delete;
 
         friend class Manager; // give Manager access to our private members
         static bool CanShutdown(){ return s_CanShutdown; }
@@ -108,6 +104,7 @@ class DLLIMPORT EditorManager : public Mgr<EditorManager>, public wxEvtHandler
         bool UpdateProjectFiles(cbProject* project);
         bool SwapActiveHeaderSource();
         bool OpenContainingFolder();
+        void CopyFullPath();
         bool CloseActive(bool dontsave = false);
         bool Close(const wxString& filename, bool dontsave = false);
         bool Close(EditorBase* editor, bool dontsave = false);
@@ -125,6 +122,10 @@ class DLLIMPORT EditorManager : public Mgr<EditorManager>, public wxEvtHandler
         bool CloseAllInTabCtrl(bool dontsave = false);
         /** Closes all editors in the same tab control as the active editor, except the editor passed as parameter. */
         bool CloseAllInTabCtrlExcept(EditorBase* editor, bool dontsave = false);
+        /// Closes all editors in the same tab control which are on the left of the passed editor.
+        bool CloseAllInTabCtrlToTheLeft(EditorBase* editor, bool dontsave = false);
+        /// Closes all editors in the same tab control which are on the right of the passed editor.
+        bool CloseAllInTabCtrlToTheRight(EditorBase* editor, bool dontsave = false);
         bool Save(const wxString& filename);
         bool Save(int index);
         bool SaveActive();
@@ -161,6 +162,7 @@ class DLLIMPORT EditorManager : public Mgr<EditorManager>, public wxEvtHandler
         void OnSaveAll(wxCommandEvent& event);
         void OnSwapHeaderSource(wxCommandEvent& event);
         void OnOpenContainingFolder(wxCommandEvent& event);
+        void OnCopyFullPath(wxCommandEvent& event);
         void OnTabPosition(wxCommandEvent& event);
         void OnProperties(wxCommandEvent& event);
         void OnAddFileToProject(wxCommandEvent& event);
@@ -174,8 +176,6 @@ class DLLIMPORT EditorManager : public Mgr<EditorManager>, public wxEvtHandler
         void OnTreeItemRightClick(wxTreeEvent &event);
         void CollectDefines(CodeBlocksEvent& event);
 
-        void OnAppActivated(CodeBlocksEvent& event);
-
     protected:
         // m_EditorsList access
         void AddEditorBase(EditorBase* eb);
@@ -184,10 +184,8 @@ class DLLIMPORT EditorManager : public Mgr<EditorManager>, public wxEvtHandler
         EditorBase* InternalGetEditorBase(int page);
 
     private:
-        EditorManager(cb_unused const EditorManager& rhs); // prevent copy construction
-
         EditorManager();
-        ~EditorManager();
+        ~EditorManager() override;
         void OnCheckForModifiedFiles(wxCommandEvent& event);
         bool IsHeaderSource(const wxFileName& candidateFile, const wxFileName& activeFile, FileType ftActive, bool& isCandidate);
         wxFileName FindHeaderSource(const wxArrayString& candidateFilesArray, const wxFileName& activeFile, bool& isCandidate);
