@@ -14,26 +14,124 @@
 #include <wx/dynarray.h>
 #include <wx/hashmap.h>
 #include <wx/treectrl.h>
+
+#include "cbexception.h"
+#include "cbtreectrl.h"
 #include "settings.h"
 #include "manager.h"
-#include "cbexception.h"
 
 // forward decls
-class wxMenuBar;
-class wxPanel;
 class cbProject;
 class EditorBase;
-class wxImageList;
 class ProjectFile;
 class FilesGroupsAndMasks;
 class cbWorkspace;
 class cbAuiNotebook;
-class wxAuiNotebookEvent;
 
-DLLIMPORT extern int ID_ProjectManager; /* Used by both Project and Editor Managers */
 WX_DEFINE_ARRAY(cbProject*, ProjectsArray);
 WX_DECLARE_HASH_MAP(cbProject*, ProjectsArray*, wxPointerHash, wxPointerEqual, DepsMap); // for project dependencies
 
+
+class DLLIMPORT cbProjectManagerUI
+{
+    public:
+        virtual ~cbProjectManagerUI() {}
+
+        virtual cbAuiNotebook* GetNotebook() = 0;
+        /** Retrieve a pointer to the project manager's tree (GUI).
+          * @return A pointer to a wxTreeCtrl window.
+          */
+        virtual cbTreeCtrl* GetTree() = 0;
+        /// Rebuild the project manager's tree.
+        virtual void RebuildTree() = 0;
+        /** Stop the tree control from updating.
+          * @note This operation is accumulative. This means you have to call
+          * UnfreezeTree() as many times as you 've called FreezeTree() for the
+          * tree control to un-freeze (except if you call UnfreezeTree(true)).
+          */
+        virtual void FreezeTree() = 0;
+        /** Le the tree control be updated again.
+          * @param force If true the tree control is forced to un-freeze. Else it
+          * depends on freeze-unfreeze balance (see note).
+          * @note This operation is accumulative. This means you have to call
+          * UnfreezeTree() as many times as you 've called FreezeTree() for the
+          * tree control to un-freeze (except if you call UnfreezeTree(true)).
+          */
+        virtual void UnfreezeTree(bool force = false) = 0;
+        /** Get the selection of the project manager's tree (GUI).
+          * This must be used instead of tree->GetSelection() because the tree
+          * has the wxTR_MULTIPLE style.
+          * This usually returns the first item in the selection list, but
+          * if there is a right-click popup menu then the user may have
+          * selected several items and right-clicked on one, so return the
+          * right-click item instead.
+          * of the first
+          * @return A wxTreeItemId of the selected tree item.
+          */
+        virtual wxTreeItemId GetTreeSelection() = 0;
+
+        virtual void ShowFileInTree(ProjectFile &projectFile) = 0;
+
+        virtual void UpdateActiveProject(cbProject *oldProject, cbProject *newProject, bool refresh) = 0;
+        virtual void RemoveProject(cbProject *project) = 0;
+        virtual void BeginLoadingWorkspace() = 0;
+        virtual void CloseWorkspace() = 0;
+        virtual void FinishLoadingProject(cbProject *project, bool newAddition, FilesGroupsAndMasks* fileGroups) = 0;
+        virtual void FinishLoadingWorkspace(cbProject *activeProject, const wxString &workspaceTitle) = 0;
+
+        /** Checks whether all projects are saved. If not, asks
+          *  the user to save and saves accordingly.
+          *  @return False if the user pressed cancel.
+          *  Note: calls QueryCloseProject for all projects.
+          */
+        virtual bool QueryCloseAllProjects() = 0;
+
+        /** Checks whether project is saved. If not, asks
+          *  the user to save and saves accordingly.
+          *  @return False if the user pressed cancel.
+          *  Note: By default this asks the user if he should
+          *  save any unmodified files in the project.
+          */
+        virtual bool QueryCloseProject(cbProject *proj, bool dontsavefiles = false) = 0;
+
+        /** Asks user to save the workspace, projects and files
+          * (Yes/No/cancel). If user pressed Yes, it saves accordingly.
+          * @return False if the user pressed cancel; true otherwise.
+          * After this function is called and returns true, it
+          * is safe to close the workspace, all files and projects
+          * without asking the user later.
+          */
+        virtual bool QueryCloseWorkspace() = 0;
+
+        /** Utility function. Displays a single selection list of a project's
+          * build targets to choose from.
+          * @param project The project to use. If NULL, the active project is used.
+          * @return The selected build target's index, or -1 if no build target was selected.
+          */
+        virtual int AskForBuildTargetIndex(cbProject* project = nullptr) = 0;
+        /** Utility function. Displays a multiple selection list of a project's
+          * build targets to choose from.
+          * @param project The project to use. If NULL, the active project is used.
+          * @return An integer array containing the selected build targets indices.
+          * This array will be empty if no build targets were selected.
+          */
+        virtual wxArrayInt AskForMultiBuildTargetIndex(cbProject* project = nullptr) = 0;
+
+        /** Displays a dialog to setup project dependencies.
+          * @param base The project to setup its dependencies. Can be NULL because there's a
+          * project selection combo in the dialog.
+          * @param parent Parent window which should be used to show the dialog.
+          */
+        virtual void ConfigureProjectDependencies(cbProject* base, wxWindow *parent) = 0;
+
+        /** Switches the management's notebook to the Projects tab */
+        virtual void SwitchToProjectsPage() = 0;
+
+        /** Reload the File system watcher for the project prj **/
+        virtual void ReloadFileSystemWatcher(cbProject* prj) = 0;
+};
+
+
 /** @brief The entry point singleton for working with projects.
   *
   * This is the project manager class. It handles all open projects and workspaces.
@@ -52,19 +150,16 @@ class DLLIMPORT ProjectManager : public Mgr<ProjectManager>, public wxEvtHandler
         friend class Mgr<ProjectManager>;
         friend class Manager; // give Manager access to our private members
 
-        ProjectManager(const ProjectManager& rhs) { cbThrow(_T("Can't call ProjectManager's copy ctor!!!")); }
-        virtual void operator=(const ProjectManager& rhs){ cbThrow(_T("Can't assign an ProjectManager* !!!")); }
-
-        cbAuiNotebook* GetNotebook() { return m_pNotebook; }
+        // FIXME(obfuscated#): Extract these two in their own class
+        cbProjectManagerUI& GetUI() { return *m_ui; }
+        void SetUI(cbProjectManagerUI *ui);
 
         const FilesGroupsAndMasks* GetFilesGroupsAndMasks() const { return m_pFileGroups; }
+        FilesGroupsAndMasks* GetFilesGroupsAndMasks() { return m_pFileGroups; }
+
+        /// Can the app shutdown? (actually: is ProjectManager busy at the moment?)
+        static bool CanShutdown() { return s_CanShutdown; }
 
-        // Can the app shutdown? (actually: is ProjectManager busy at the moment?)
-        static bool CanShutdown(){ return s_CanShutdown; }
-        /// Application menu creation. Called by the application only.
-        static void CreateMenu(wxMenuBar* menuBar);
-        /// Application menu removal. Called by the application only.
-        void ReleaseMenu(wxMenuBar* menuBar);
         /** Retrieve the default path for new projects.
           * @return The default path for new projects. Contains trailing path separator.
           * @note This might be empty if not configured before...
@@ -109,25 +204,31 @@ class DLLIMPORT ProjectManager : public Mgr<ProjectManager>, public wxEvtHandler
           * is returned. Else the return value is NULL.
           */
         cbProject* LoadProject(const wxString& filename, bool activateIt = true);
+
+        /** Reloads a project and tries to keep everything the same (project order, dependencies, active project)
+          * @param project the project that will be reloaded, the pointer will be invalid after the call.
+          */
+        void ReloadProject(cbProject *project);
+
         /** Save a project to disk.
           * @param project A pointer to the project to save.
-          * @return True if saving was succesful, false if not.
+          * @return True if saving was successful, false if not.
           */
         bool SaveProject(cbProject* project);
         /** Save a project to disk, asking for a filename.
           * @param project A pointer to the project to save.
-          * @return True if saving was succesful, false if not.
+          * @return True if saving was successful, false if not.
           * @note A false return value doesn't necessarily mean failure. The user
           * might have cancelled the SaveAs dialog...
           */
         bool SaveProjectAs(cbProject* project);
         /** Save the active project to disk. Same as SaveProject(GetActiveProject()).
-          * @return True if saving was succesful, false if not.
+          * @return True if saving was successful, false if not.
           */
         bool SaveActiveProject();
         /** Save the active project to disk, asking for a filename.
           * Same as SaveProjectAs(GetActiveProject()).
-          * @return True if saving was succesful, false if not.
+          * @return True if saving was successful, false if not.
           * @note A false return value doesn't necessarily mean failure. The user
           * might have cancelled the SaveAs dialog...
           */
@@ -151,38 +252,10 @@ class DLLIMPORT ProjectManager : public Mgr<ProjectManager>, public wxEvtHandler
           * @return True if all projects were closed, false if even one close operation failed.
           */
         bool CloseAllProjects(bool dontsave = false);
-        /** Checks whether all projects are saved. If not, asks
-          *  the user to save and saves accordingly.
-          *  @return False if the user pressed cancel.
-          *  Note: calls QueryCloseProject for all projects.
-          */
-        bool QueryCloseAllProjects();
 
-        /** Checks whether project is saved. If not, asks
-          *  the user to save and saves accordingly.
-          *  @return False if the user pressed cancel.
-          *  Note: By default this asks the user if he should
-          *  save any unmodified files in the project.
-          */
-        bool QueryCloseProject(cbProject *proj,bool dontsavefiles=false);
-
-        /** Move a project up in the project manager tree. This effectively
-          * re-orders the projects build order.
-          * @param project The project to move up.
-          * @param warpAround If true and the project is at the top of the list order,
-          * then it wraps and goes to the bottom of the list.
-          */
-        void MoveProjectUp(cbProject* project, bool warpAround = false);
-        /** Move a project down in the project manager tree. This effectively
-          * re-orders the projects build order.
-          * @param project The project to move down.
-          * @param warpAround If true and the project is at the bottom of the list order,
-          * then it wraps and goes to the top of the list.
-          */
-        void MoveProjectDown(cbProject* project, bool warpAround = false);
         /** Create a new empty project.
           * @param filename the project's filename
-          * @return A pointer to the new project if succesful, or NULL if not.
+          * @return A pointer to the new project if successful, or NULL if not.
           * @note When the new project is created, if no filename parameter was supplied,
           * it asks the user where to save it.
           * If the user cancels the Save dialog, then NULL is returned from this function.
@@ -199,7 +272,7 @@ class DLLIMPORT ProjectManager : public Mgr<ProjectManager>, public wxEvtHandler
           * If the project has more than one build targets, a dialog appears so
           * that the user can select which build target this file should belong to.
           */
-        int AddFileToProject(const wxString& filename, cbProject* project = 0L, int target = -1);
+        int AddFileToProject(const wxString& filename, cbProject* project = nullptr, int target = -1);
         /** Add a file to a project. This function comes in two versions. This version,
           * expects an array of build target indices for the added file to belong to.
           * @param filename The file to add to the project.
@@ -245,19 +318,6 @@ class DLLIMPORT ProjectManager : public Mgr<ProjectManager>, public wxEvtHandler
           * @param project The project to remove this file from. If NULL, the active project is used.
           */
         void RemoveFileFromProject(ProjectFile* pfile, cbProject* project);
-        /** Utility function. Displays a single selection list of a project's
-          * build targets to choose from.
-          * @param project The project to use. If NULL, the active project is used.
-          * @return The selected build target's index, or -1 if no build target was selected.
-          */
-        int AskForBuildTargetIndex(cbProject* project = 0L);
-        /** Utility function. Displays a multiple selection list of a project's
-          * build targets to choose from.
-          * @param project The project to use. If NULL, the active project is used.
-          * @return An integer array containing the selected build targets indices.
-          * This array will be empty if no build targets were selected.
-          */
-        wxArrayInt AskForMultiBuildTargetIndex(cbProject* project = 0L);
         /** Load a workspace.
           * @param filename The workspace to open.
           * @return True if the workspace loads succefully, false if not.
@@ -312,7 +372,6 @@ class DLLIMPORT ProjectManager : public Mgr<ProjectManager>, public wxEvtHandler
           */
         cbWorkspace* GetWorkspace();
 
-
         /** @brief Adds a project as a dependency of another project.
           * Projects inside workspaces allow you to set dependencies between them.
           * When project A depends on project B, this means that before building
@@ -343,62 +402,11 @@ class DLLIMPORT ProjectManager : public Mgr<ProjectManager>, public wxEvtHandler
           * @return An array of project dependencies, or NULL if no dependencies are set for @c base.
           */
         const ProjectsArray* GetDependenciesForProject(cbProject* base);
-        /** Displays a dialog to setup project dependencies.
-          * @param base The project to setup its dependencies. Can be NULL (default) because there's a project selection combo in the dialog.
-          */
-        void ConfigureProjectDependencies(cbProject* base = 0);
         /** Checks for circular dependencies between @c base and @c dependsOn.
           * @return True if circular dependency is detected, false if it isn't.
           */
         bool CausesCircularDependency(cbProject* base, cbProject* dependsOn);
 
-
-        /// Rebuild the project manager's tree.
-        void RebuildTree();
-        /** Stop the tree control from updating.
-          * @note This operation is accumulative. This means you have to call
-          * UnfreezeTree() as many times as you 've called FreezeTree() for the
-          * tree control to un-freeze (except if you call UnfreezeTree(true)).
-          */
-        void FreezeTree();
-        /** Le the tree control be updated again.
-          * @param force If true the tree control is forced to un-freeze. Else it
-          * depends on freeze-unfreeze balance (see note).
-          * @note This operation is accumulative. This means you have to call
-          * UnfreezeTree() as many times as you 've called FreezeTree() for the
-          * tree control to un-freeze (except if you call UnfreezeTree(true)).
-          */
-        void UnfreezeTree(bool force = false);
-        /** Retrieve a pointer to the project manager's tree (GUI).
-          * @return A pointer to a wxTreeCtrl window.
-          */
-        wxTreeCtrl* GetTree(){ return m_pTree; }
-        /** Retrieve a pointer to the project manager's panel (GUI). This panel
-          * is the parent of the project manager's tree obtained through GetTree().
-          * @return A pointer to a wxPanel window.
-          */
-        wxMenu* GetProjectMenu();
-        /** Sets the Top Editor (the active editor from the last session) */
-        void SetTopEditor(EditorBase* ed);
-        /** @return The Top Editor */
-        EditorBase* GetTopEditor() const;
-
-        /** @return The workspace icon index in the image list.
-            @param  read_only Return the read-only icon for a workspace?
-         */
-        int WorkspaceIconIndex(bool read_only = false);
-        /** @return The project icon index in the image list.
-            @param  read_only Return the read-only icon for a project?
-         */
-        int ProjectIconIndex(bool read_only = false);
-        /** @return The folder icon index in the image list. */
-        int FolderIconIndex();
-        /** @return The virtual folder icon index in the image list. */
-        int VirtualFolderIconIndex();
-
-        /** Check if one of the open projects has been modified outside the IDE. If so, ask to reload it. */
-        void CheckForExternallyModifiedProjects();
-
         /** Sends message to the plugins that the workspace has been changed */
         void WorkspaceChanged();
 
@@ -424,90 +432,44 @@ class DLLIMPORT ProjectManager : public Mgr<ProjectManager>, public wxEvtHandler
           * @note A call to BeginLoadingWorkspace() must have preceded.
           */
         void EndLoadingWorkspace();
+
+        ProjectManager(const ProjectManager&) = delete;
+        ProjectManager& operator=(const ProjectManager&) = delete;
+
+        /// This method should be called when the applications is started by a plugin.
+        /// There is only one plugin which could be running the application.
+        /// Running means that plugin has started the executable and it is waiting for it to finish.
+        void SetIsRunning(cbPlugin *plugin);
+
+        /// Return a pointer to the plugin which is running the application.
+        cbPlugin* GetIsRunning() const;
+
+        /** Return the project which has the file in it, also return the pointer to the ProjectFile object. */
+        cbProject* FindProjectForFile(const wxString& file, ProjectFile **resultFile,
+                                      bool isRelative, bool isUnixFilename);
+
     private:
         ProjectManager();
-        ~ProjectManager();
-
-        /** Asks user to save the workspace, projects and files
-          * (Yes/No/cancel). If user pressed Yes, it saves accordingly.
-          * @return False if the user pressed cancel; true otherwise.
-          * After this function is called and returns true, it
-          * is safe to close the workspace, all files and projects
-          * without asking the user later.
-          */
-        bool QueryCloseWorkspace();
-
-        void InitPane();
-        void BuildTree();
-        void ShowMenu(wxTreeItemId id, const wxPoint& pt);
-        void OnTabContextMenu(wxAuiNotebookEvent& event);
-        void OnTabPosition(wxCommandEvent& event);
-        void OnProjectFileActivated(wxTreeEvent& event);
-        void OnExecParameters(wxCommandEvent& event);
-        void OnTreeItemRightClick(wxTreeEvent& event);
-        void OnTreeBeginDrag(wxTreeEvent& event);
-        void OnTreeEndDrag(wxTreeEvent& event);
-        void OnRightClick(wxCommandEvent& event);
-        void OnRenameWorkspace(wxCommandEvent& event);
-        void OnSaveWorkspace(wxCommandEvent& event);
-        void OnSaveAsWorkspace(wxCommandEvent& event);
-        void OnCloseWorkspace(wxCommandEvent& event);
-        void OnSetActiveProject(wxCommandEvent& event);
-        void OnAddFilesToProjectRecursively(wxCommandEvent& event);
-        void OnAddFileToProject(wxCommandEvent& event);
-        void OnRemoveFileFromProject(wxCommandEvent& event);
-        void OnRenameFile(wxCommandEvent& event);
-        void OnSaveProject(wxCommandEvent& event);
-        void OnCloseProject(wxCommandEvent& event);
-        void OnSaveFile(wxCommandEvent& event);
-        void OnCloseFile(wxCommandEvent& event);
-        void OnOpenFile(wxCommandEvent& event);
-        void OnOpenWith(wxCommandEvent& event);
-        void OnProperties(wxCommandEvent& event);
-        void OnNotes(wxCommandEvent& event);
-        void OnGotoFile(wxCommandEvent& event);
-        void OnViewCategorize(wxCommandEvent& event);
-        void OnViewUseFolders(wxCommandEvent& event);
-        void OnViewFileMasks(wxCommandEvent& event);
-        void OnFindFile(wxCommandEvent& event);
-        wxTreeItemId FindItem(wxTreeItemId Node, const wxString& Search) const;
-        void OnBeginEditNode(wxTreeEvent& event);
-        void OnEndEditNode(wxTreeEvent& event);
-        void OnAddVirtualFolder(wxCommandEvent& event);
-        void OnDeleteVirtualFolder(wxCommandEvent& event);
-        void OnUpdateUI(wxUpdateUIEvent& event);
-        void OnIdle(wxIdleEvent& event);
+        ~ProjectManager() override;
         void OnAppDoneStartup(CodeBlocksEvent& event);
-        void OnKeyDown(wxTreeEvent& event);
+        int  DoAddFileToProject(const wxString& filename, cbProject* project, wxArrayInt& targets);
 
-        void DoOpenSelectedFile();
-        void DoOpenFile(ProjectFile* pf, const wxString& filename);
-        int DoAddFileToProject(const wxString& filename, cbProject* project, wxArrayInt& targets);
-        void RemoveFilesRecursively(wxTreeItemId& sel_id);
-
-        cbAuiNotebook* m_pNotebook;
-        wxTreeCtrl* m_pTree;
-        wxTreeItemId m_TreeRoot;
-        cbProject* m_pActiveProject;
-        wxImageList* m_pImages;
-        ProjectsArray* m_pProjects;
-        DepsMap m_ProjectDeps;
-        cbWorkspace* m_pWorkspace;
-        bool m_TreeCategorize;
-        bool m_TreeUseFolders;
+        cbProjectManagerUI *m_ui;
+        cbProject*           m_pActiveProject;
+        cbProject*           m_pProjectToActivate;
+        ProjectsArray*       m_pProjects;
+        DepsMap              m_ProjectDeps;
+        cbWorkspace*         m_pWorkspace;
         FilesGroupsAndMasks* m_pFileGroups;
-        int m_TreeFreezeCounter;
-        bool m_IsLoadingProject;
-        bool m_IsLoadingWorkspace;
-        bool m_IsClosingProject;
-        bool m_IsClosingWorkspace;
-        wxString m_InitialDir;
-        wxTreeItemId m_DraggingItem;
-        bool m_isCheckingForExternallyModifiedProjects;
-        bool m_CanSendWorkspaceChanged;
+        bool                 m_IsLoadingProject;
+        bool                 m_IsLoadingWorkspace;
+        bool                 m_IsClosingProject;
+        bool                 m_IsClosingWorkspace;
+        wxString             m_InitialDir;
+        bool                 m_CanSendWorkspaceChanged;
+        cbPlugin*            m_RunningPlugin;
 
         DECLARE_EVENT_TABLE()
 };
 
 #endif // PROJECTMANAGER_H
-
