@@ -6,6 +6,10 @@
 #ifndef SDK_EVENTS_H
 #define SDK_EVENTS_H
 
+#include <wx/bitmap.h>
+#if wxCHECK_VERSION(3, 1, 6)
+#include <wx/bmpbndl.h>
+#endif
 #include <wx/event.h>
 #include <wx/intl.h>
 #include "settings.h"
@@ -36,7 +40,7 @@ class EVTIMPORT CodeBlocksEvent : public wxCommandEvent
 			m_pPlugin(event.m_pPlugin),
 			m_X(event.m_X),
 			m_Y(event.m_Y) {}
-		virtual wxEvent *Clone() const { return new CodeBlocksEvent(*this); }
+		wxEvent *Clone() const override { return new CodeBlocksEvent(*this); }
 
 		cbProject* GetProject() const             { return m_pProject;    }
 		void       SetProject(cbProject* project) { m_pProject = project; }
@@ -56,13 +60,20 @@ class EVTIMPORT CodeBlocksEvent : public wxCommandEvent
 		int  GetY() const { return m_Y; }
 		void SetY(int y)  { m_Y = y;    }
 
-		const wxString& GetBuildTargetName() const                 { return m_TargetName;   }
-		void            SetBuildTargetName(const wxString& target) { m_TargetName = target; }
+		const wxString& GetBuildTargetName() const                 { return m_NewName;   }
+		void            SetBuildTargetName(const wxString& target) { m_NewName = target; }
 
 		// the following two functions are only valid for EVT_BUILDTARGET_RENAMED
 		// and EVT_BUILDTARGET_SELECTED events
-		const wxString& GetOldBuildTargetName() const                 { return m_OldTargetName;   }
-		void            SetOldBuildTargetName(const wxString& target) { m_OldTargetName = target; }
+		const wxString& GetOldBuildTargetName() const                 { return m_OldName;   }
+		void            SetOldBuildTargetName(const wxString& target) { m_OldName = target; }
+
+		// the following four functions are only valid for EVT_PROJECT_FILE_RENAMED event
+		const wxString& GetNewFileName() const                 { return m_NewName;   }
+		void            SetNewFileName(const wxString& target) { m_NewName = target; }
+		const wxString& GetOldFileName() const                 { return m_OldName;   }
+		void            SetOldFileName(const wxString& target) { m_OldName = target; }
+
 	protected:
 		cbProject*  m_pProject;
 		EditorBase* m_pEditor;
@@ -72,8 +83,8 @@ class EVTIMPORT CodeBlocksEvent : public wxCommandEvent
 		int m_X;
 		int m_Y;
 
-		wxString m_TargetName;
-		wxString m_OldTargetName;
+		wxString m_NewName;
+		wxString m_OldName;
 	private:
 		DECLARE_DYNAMIC_CLASS(CodeBlocksEvent)
 };
@@ -130,7 +141,7 @@ class EVTIMPORT CodeBlocksDockEvent : public wxEvent
             bitmap(rhs.bitmap)
         {
         }
-		virtual wxEvent *Clone() const { return new CodeBlocksDockEvent(*this); }
+		wxEvent *Clone() const override { return new CodeBlocksDockEvent(*this); }
 
         wxString name;      ///< Dock's name. Must be unique. If empty, a unique name will be assigned.
         wxString title;     ///< Dock's title.
@@ -165,7 +176,7 @@ class EVTIMPORT CodeBlocksLayoutEvent : public wxEvent
         CodeBlocksLayoutEvent(const CodeBlocksLayoutEvent& rhs)
             : wxEvent(rhs), layout(rhs.layout)
         {}
-		virtual wxEvent *Clone() const { return new CodeBlocksLayoutEvent(*this); }
+		wxEvent *Clone() const override { return new CodeBlocksLayoutEvent(*this); }
 
         wxString layout;      ///< Layout's name.
 	private:
@@ -182,21 +193,33 @@ typedef void (wxEvtHandler::*CodeBlocksLayoutEventFunction)(CodeBlocksLayoutEven
 class EVTIMPORT CodeBlocksLogEvent : public wxEvent
 {
     public:
+#if wxCHECK_VERSION(3, 1, 6)
+        CodeBlocksLogEvent(wxEventType commandType = wxEVT_NULL, Logger* logger = nullptr, const wxString& title = wxEmptyString, wxBitmapBundle *icon = nullptr);
+        CodeBlocksLogEvent(wxEventType commandType, wxWindow* window, const wxString& title = wxEmptyString, wxBitmapBundle *icon = nullptr);
+        CodeBlocksLogEvent(wxEventType commandType, int logIndex, const wxString& title = wxEmptyString, wxBitmapBundle *icon = nullptr);
+#else
         CodeBlocksLogEvent(wxEventType commandType = wxEVT_NULL, Logger* logger = nullptr, const wxString& title = wxEmptyString, wxBitmap *icon = nullptr);
         CodeBlocksLogEvent(wxEventType commandType, wxWindow* window, const wxString& title = wxEmptyString, wxBitmap *icon = nullptr);
         CodeBlocksLogEvent(wxEventType commandType, int logIndex, const wxString& title = wxEmptyString, wxBitmap *icon = nullptr);
+#endif
         CodeBlocksLogEvent(const CodeBlocksLogEvent& rhs);
 
-		virtual wxEvent *Clone() const { return new CodeBlocksLogEvent(*this); }
+        wxEvent *Clone() const override { return new CodeBlocksLogEvent(*this); }
 
         Logger* logger; ///< The logger.
         int logIndex; ///< The logger's index.
-		wxBitmap *icon; ///< The logger's icon. Valid only for cbEVT_ADD_LOG_WINDOW.
-		wxString title; ///< The logger's title. Valid only for cbEVT_ADD_LOG_WINDOW.
-		wxWindow* window; ///< A non-logger window. Needed at least by cbEVT_REMOVE_LOG_WINDOW.
-	private:
-		DECLARE_DYNAMIC_CLASS(CodeBlocksLogEvent)
+
+#if wxCHECK_VERSION(3, 1, 6)
+        wxBitmapBundle *icon; ///< The logger's icon. Valid only for cbEVT_ADD_LOG_WINDOW.
+#else
+        wxBitmap *icon; ///< The logger's icon. Valid only for cbEVT_ADD_LOG_WINDOW.
+#endif
+        wxString title; ///< The logger's title. Valid only for cbEVT_ADD_LOG_WINDOW.
+        wxWindow* window; ///< A non-logger window. Needed at least by cbEVT_REMOVE_LOG_WINDOW.
+    private:
+        DECLARE_DYNAMIC_CLASS(CodeBlocksLogEvent)
 };
+
 typedef void (wxEvtHandler::*CodeBlocksLogEventFunction)(CodeBlocksLogEvent&);
 
 
@@ -221,7 +244,7 @@ public:
         SetString(GetString().c_str());
     }
 
-    virtual wxEvent *Clone() const
+    wxEvent *Clone() const override
     {
         return new CodeBlocksThreadEvent(*this);
     }
@@ -328,6 +351,8 @@ extern EVTIMPORT const wxEventType cbEVT_PROJECT_FILE_REMOVED;
 #define EVT_PROJECT_FILE_REMOVED(fn) DECLARE_EVENT_TABLE_ENTRY( cbEVT_PROJECT_FILE_REMOVED, -1, -1, (wxObjectEventFunction)(wxEventFunction)(CodeBlocksEventFunction)&fn, (wxObject *) NULL ),
 extern EVTIMPORT const wxEventType cbEVT_PROJECT_FILE_CHANGED;
 #define EVT_PROJECT_FILE_CHANGED(fn) DECLARE_EVENT_TABLE_ENTRY( cbEVT_PROJECT_FILE_CHANGED, -1, -1, (wxObjectEventFunction)(wxEventFunction)(CodeBlocksEventFunction)&fn, (wxObject *) NULL ),
+extern EVTIMPORT const wxEventType cbEVT_PROJECT_FILE_RENAMED;
+#define EVT_PROJECT_FILE_RENAMED(fn) DECLARE_EVENT_TABLE_ENTRY( cbEVT_PROJECT_FILE_RENAMED, -1, -1, (wxObjectEventFunction)(wxEventFunction)(CodeBlocksEventFunction)&fn, (wxObject *) NULL ),
 extern EVTIMPORT const wxEventType cbEVT_PROJECT_POPUP_MENU;
 #define EVT_PROJECT_POPUP_MENU(fn) DECLARE_EVENT_TABLE_ENTRY( cbEVT_PROJECT_POPUP_MENU, -1, -1, (wxObjectEventFunction)(wxEventFunction)(CodeBlocksEventFunction)&fn, (wxObject *) NULL ),
 extern EVTIMPORT const wxEventType cbEVT_PROJECT_TARGETS_MODIFIED;
@@ -432,8 +457,17 @@ extern EVTIMPORT const wxEventType cbEVT_DEBUGGER_STARTED;
 #define EVT_DEBUGGER_STARTED(fn) DECLARE_EVENT_TABLE_ENTRY( cbEVT_DEBUGGER_STARTED, -1, -1, (wxObjectEventFunction)(wxEventFunction)(CodeBlocksEventFunction)&fn, (wxObject *) NULL ),
 extern EVTIMPORT const wxEventType cbEVT_DEBUGGER_PAUSED;
 #define EVT_DEBUGGER_PAUSED(fn) DECLARE_EVENT_TABLE_ENTRY( cbEVT_DEBUGGER_PAUSED, -1, -1, (wxObjectEventFunction)(wxEventFunction)(CodeBlocksEventFunction)&fn, (wxObject *) NULL ),
+extern EVTIMPORT const wxEventType cbEVT_DEBUGGER_CONTINUED;
+#define cbEVT_DEBUGGER_CONTINUED(fn) DECLARE_EVENT_TABLE_ENTRY( cbEVT_DEBUGGER_CONTINUED, -1, -1, (wxObjectEventFunction)(wxEventFunction)(CodeBlocksEventFunction)&fn, (wxObject *) NULL ),
 extern EVTIMPORT const wxEventType cbEVT_DEBUGGER_FINISHED;
 #define EVT_DEBUGGER_FINISHED(fn) DECLARE_EVENT_TABLE_ENTRY( cbEVT_DEBUGGER_FINISHED, -1, -1, (wxObjectEventFunction)(wxEventFunction)(CodeBlocksEventFunction)&fn, (wxObject *) NULL ),
+extern EVTIMPORT const wxEventType cbEVT_DEBUGGER_CURSOR_CHANGED;
+#define EVT_DEBUGGER_CURSOR_CHANGED(fn) DECLARE_EVENT_TABLE_ENTRY( cbEVT_DEBUGGER_CURSOR_CHANGED, -1, -1, (wxObjectEventFunction)(wxEventFunction)(CodeBlocksEventFunction)&fn, (wxObject *) NULL ),
+/// Event sent when the data for a particular debug window is acquired by the debugger plugin and
+/// can be presented to the user. Calling GetInt on the event object can be used to find out the
+/// type of window which has been updated. The value has type cbDebuggerPlugin::DebugWindows.
+extern EVTIMPORT const wxEventType cbEVT_DEBUGGER_UPDATED;
+#define EVT_DEBUGGER_UPDATED(fn) DECLARE_EVENT_TABLE_ENTRY( cbEVT_DEBUGGER_UPDATED, -1, -1, (wxObjectEventFunction)(wxEventFunction)(CodeBlocksEventFunction)&fn, (wxObject *) NULL ),
 
 // logger-related events
 
@@ -479,16 +513,17 @@ extern EVTIMPORT const wxEventType cbEVT_SHOW_CALL_TIP;
 // settings events
 
 // event.GetInt() returns value of type cbSettingsType::Type indicating which setting group was changed
-struct cbSettingsType
+enum class cbSettingsType : int
 {
-    enum Type
-    {
-        Compiler,
-        Debugger,
-        Environment,
-        Editor,
-        Plugins
-    };
+    First,
+    Compiler = First,
+    Debugger,
+    Environment,
+    Editor,
+    Plugins,
+    Scripting,
+    BuildOptions,
+    Last // use only to convert from ints
 };
 extern EVTIMPORT const wxEventType cbEVT_SETTINGS_CHANGED;
 #define EVT_SETTINGS_CHANGED(fn) DECLARE_EVENT_TABLE_ENTRY( cbEVT_SETTINGS_CHANGED, -1, -1, (wxObjectEventFunction)(wxEventFunction)(CodeBlocksEventFunction)&fn, (wxObject *) NULL ),
